==> jc-1.4.0.tar.gz: org/dellroad/jc/cgen/escape/StackAlloc.c <==
// class org.dellroad.jc.cgen.escape.StackAlloc

// class file dependencies
// @dep_class 52a05cb5e85a24ee java_lang_Boolean
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class e19a02dee62a8866 org_dellroad_jc_cgen_escape_StackAlloc
// @dep_class fc12513d0e867dd9 soot_Local
// @dep_class 277f133500573bf0 soot_Value
// @dep_class bfceec22e8ffee79 soot_jimple_AssignStmt
// @dep_class 3650ad26817a710 soot_jimple_Stmt

// header file dependencies
// @dep_header java_lang_Boolean
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header org_dellroad_jc_cgen_escape_StackAlloc
// @dep_header soot_Local
// @dep_header soot_Value
// @dep_header soot_jimple_AssignStmt
// @dep_header soot_jimple_Stmt

#include "jc_defs.h"

#include "java/lang/Boolean.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "org/dellroad/jc/cgen/escape/StackAlloc.h"
#include "soot/Local.h"
#include "soot/Value.h"
#include "soot/jimple/AssignStmt.h"
#include "soot/jimple/Stmt.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// soot.jimple.AssignStmt stmt
static _jc_field _jc_org_dellroad_jc_cgen_escape_StackAlloc$field_info$stmt = {
	.name=		"stmt",
	.signature=	"Lsoot/jimple/AssignStmt;",
	.class=		&_jc_org_dellroad_jc_cgen_escape_StackAlloc$type,
	.type=		&_jc_soot_jimple_AssignStmt$type,
	.access_flags=	0,
	.offset=	_JC_OFFSETOF(_jc_org_dellroad_jc_cgen_escape_StackAlloc$object, refs[-1].org_dellroad_jc_cgen_escape_StackAlloc.stmt),
};

// soot.Local local
static _jc_field _jc_org_dellroad_jc_cgen_escape_StackAlloc$field_info$local = {
	.name=		"local",
	.signature=	"Lsoot/Local;",
	.class=		&_jc_org_dellroad_jc_cgen_escape_StackAlloc$type,
	.type=		&_jc_soot_Local$type,
	.access_flags=	0,
	.offset=	_JC_OFFSETOF(_jc_org_dellroad_jc_cgen_escape_StackAlloc$object, refs[-1].org_dellroad_jc_cgen_escape_StackAlloc.local),
};

// soot.Value value
static _jc_field _jc_org_dellroad_jc_cgen_escape_StackAlloc$field_info$value = {
	.name=		"value",
	.signature=	"Lsoot/Value;",
	.class=		&_jc_org_dellroad_jc_cgen_escape_StackAlloc$type,
	.type=		&_jc_soot_Value$type,
	.access_flags=	0,
	.offset=	_JC_OFFSETOF(_jc_org_dellroad_jc_cgen_escape_StackAlloc$object, refs[-1].org_dellroad_jc_cgen_escape_StackAlloc.value),
};

// java.lang.Boolean escapes
static _jc_field _jc_org_dellroad_jc_cgen_escape_StackAlloc$field_info$escapes = {
	.name=		"escapes",
	.signature=	"Ljava/lang/Boolean;",
	.class=		&_jc_org_dellroad_jc_cgen_escape_StackAlloc$type,
	.type=		&_jc_java_lang_Boolean$type,
	.access_flags=	0,
	.offset=	_JC_OFFSETOF(_jc_org_dellroad_jc_cgen_escape_StackAlloc$object, refs[-1].org_dellroad_jc_cgen_escape_StackAlloc.escapes),
};

// int size
static _jc_field _jc_org_dellroad_jc_cgen_escape_StackAlloc$field_info$size = {
	.name=		"size",
	.signature=	"I",
	.class=		&_jc_org_dellroad_jc_cgen_escape_StackAlloc$type,
	.type=		&_jc_int$prim$type,
	.access_flags=	0,
	.offset=	_JC_OFFSETOF(_jc_org_dellroad_jc_cgen_escape_StackAlloc$object, nonrefs.org_dellroad_jc_cgen_escape_StackAlloc.size),
};

// int cost
static _jc_field _jc_org_dellroad_jc_cgen_escape_StackAlloc$field_info$cost = {
	.name=		"cost",
	.signature=	"I",
	.class=		&_jc_org_dellroad_jc_cgen_escape_StackAlloc$type,
	.type=		&_jc_int$prim$type,
	.access_flags=	0,
	.offset=	_JC_OFFSETOF(_jc_org_dellroad_jc_cgen_escape_StackAlloc$object, nonrefs.org_dellroad_jc_cgen_escape_StackAlloc.cost),
};

// Fields
static _jc_field *const _jc_org_dellroad_jc_cgen_escape_StackAlloc$fields[] = {
	&_jc_org_dellroad_jc_cgen_escape_StackAlloc$field_info$escapes,
	&_jc_org_dellroad_jc_cgen_escape_StackAlloc$field_info$local,
	&_jc_org_dellroad_jc_cgen_escape_StackAlloc$field_info$stmt,
	&_jc_org_dellroad_jc_cgen_escape_StackAlloc$field_info$value,
	&_jc_org_dellroad_jc_cgen_escape_StackAlloc$field_info$cost,
	&_jc_org_dellroad_jc_cgen_escape_StackAlloc$field_info$size
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(soot.jimple.Stmt)
//

static _jc_linenum _jc_org_dellroad_jc_cgen_escape_StackAlloc$linenum_table$_init$3c88635eae989746[];

static const unsigned char _jc_org_dellroad_jc_cgen_escape_StackAlloc$param_ptypes$_init$3c88635eae989746[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_org_dellroad_jc_cgen_escape_StackAlloc$param_types$_init$3c88635eae989746[] = {
	&_jc_soot_jimple_Stmt$type
};

_jc_method _jc_org_dellroad_jc_cgen_escape_StackAlloc$method_info$_init$3c88635eae989746 = {
	.name=			"<init>",
	.signature=		"(Lsoot/jimple/Stmt;)V",
	.class=			&_jc_org_dellroad_jc_cgen_escape_StackAlloc$type,
	.param_types=		&_jc_org_dellroad_jc_cgen_escape_StackAlloc$param_types$_init$3c88635eae989746,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_org_dellroad_jc_cgen_escape_StackAlloc$param_ptypes$_init$3c88635eae989746,
	.signature_hash=	_JC_JLONG(0x3c88635eae989746),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_org_dellroad_jc_cgen_escape_StackAlloc$method$_init$3c88635eae989746,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	4,
	      .table=	_jc_org_dellroad_jc_cgen_escape_StackAlloc$linenum_table$_init$3c88635eae989746
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(org_dellroad_jc_cgen_escape_StackAlloc, _init$3c88635eae989746);

void
_jc_org_dellroad_jc_cgen_escape_StackAlloc$method$_init$3c88635eae989746(_jc_env *const env, _jc_org_dellroad_jc_cgen_escape_StackAlloc$object *this, _jc_object *param0)
{
	struct _jc_org_dellroad_jc_cgen_escape_StackAlloc$object *r0;
	struct _jc_object *r1;
	struct _jc_object *r2;
	struct _jc_object *r3;
	struct _jc_object *r4;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(27);				// 0
	r2 = _JC_CAST(env, &_jc_soot_jimple_AssignStmt$type, r1);
	_JC_REF_FIELD(env, r0, org_dellroad_jc_cgen_escape_StackAlloc, stmt) = r2;
	_JC_LINE_NUMBER(28);				// 1
	r2 = _JC_REF_FIELD(env, r0, org_dellroad_jc_cgen_escape_StackAlloc, stmt);
	r3 = _JC_INVOKE_INTERFACE(env, r2, _JC_JLONG(0x81175b6a6f9b0911), _jc_object *);
	r4 = _JC_CAST(env, &_jc_soot_Local$type, r3);
	_JC_REF_FIELD(env, r0, org_dellroad_jc_cgen_escape_StackAlloc, local) = r4;
	_JC_LINE_NUMBER(29);				// 2
	r2 = _JC_REF_FIELD(env, r0, org_dellroad_jc_cgen_escape_StackAlloc, stmt);
	r3 = _JC_INVOKE_INTERFACE(env, r2, _JC_JLONG(0xb163824a99afafb3), _jc_object *);
	_JC_REF_FIELD(env, r0, org_dellroad_jc_cgen_escape_StackAlloc, value) = r3;
	_JC_LINE_NUMBER(30);				// 3
	return;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_org_dellroad_jc_cgen_escape_StackAlloc$methods[] = {
	&_jc_org_dellroad_jc_cgen_escape_StackAlloc$method_info$_init$3c88635eae989746
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_org_dellroad_jc_cgen_escape_StackAlloc$instanceof_hash_bucket_102[] = {
	&_jc_org_dellroad_jc_cgen_escape_StackAlloc$type,
	_JC_NULL
};
static _jc_type *const _jc_org_dellroad_jc_cgen_escape_StackAlloc$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_org_dellroad_jc_cgen_escape_StackAlloc$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[102]=	_jc_org_dellroad_jc_cgen_escape_StackAlloc$instanceof_hash_bucket_102,
	[113]=	_jc_org_dellroad_jc_cgen_escape_StackAlloc$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_org_dellroad_jc_cgen_escape_StackAlloc$class_depends[] = {
	{ "java/lang/Boolean",	_JC_JLONG(0x52a05cb5e85a24ee) },
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "soot/Local",	_JC_JLONG(0xfc12513d0e867dd9) },
	{ "soot/Value",	_JC_JLONG(0x277f133500573bf0) },
	{ "soot/jimple/AssignStmt",	_JC_JLONG(0xbfceec22e8ffee79) },
	{ "soot/jimple/Stmt",	_JC_JLONG(0x3650ad26817a710) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_org_dellroad_jc_cgen_escape_StackAlloc$vtype _jc_org_dellroad_jc_cgen_escape_StackAlloc$type = {
    .type= {
	.name=			"org/dellroad/jc/cgen/escape/StackAlloc",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		0,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		11,
		.hash=			_JC_JLONG(0xe19a02dee62a8866),
		.source_file=		"StackAlloc.java",
		.instance_size=		sizeof(_jc_org_dellroad_jc_cgen_escape_StackAlloc$refs) + sizeof(_jc_org_dellroad_jc_cgen_escape_StackAlloc$object),
		.num_virtual_refs=	4,
		.num_fields=		sizeof(_jc_org_dellroad_jc_cgen_escape_StackAlloc$fields) / sizeof(*_jc_org_dellroad_jc_cgen_escape_StackAlloc$fields),
		.fields=		_jc_org_dellroad_jc_cgen_escape_StackAlloc$fields,
		.num_methods=		sizeof(_jc_org_dellroad_jc_cgen_escape_StackAlloc$methods) / sizeof(*_jc_org_dellroad_jc_cgen_escape_StackAlloc$methods),
		.methods=		_jc_org_dellroad_jc_cgen_escape_StackAlloc$methods,
		.instanceof_hash_table=	_jc_org_dellroad_jc_cgen_escape_StackAlloc$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_org_dellroad_jc_cgen_escape_StackAlloc$class_depends) / sizeof(*_jc_org_dellroad_jc_cgen_escape_StackAlloc$class_depends),
		.class_depends=		_jc_org_dellroad_jc_cgen_escape_StackAlloc$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.org_dellroad_jc_cgen_escape_StackAlloc= {
	},
    }
};

==> jc-1.4.5.tar.gz: org/dellroad/jc/cgen/escape/StackAlloc.c <==
// class org.dellroad.jc.cgen.escape.StackAlloc

// class file dependencies
// @dep_class 52a05cb5e85a24ee java_lang_Boolean
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class e19a02dee62a8866 org_dellroad_jc_cgen_escape_StackAlloc
// @dep_class fc12513d0e867dd9 soot_Local
// @dep_class 277f133500573bf0 soot_Value
// @dep_class bfceec22e8ffee79 soot_jimple_AssignStmt
// @dep_class 3650ad26817a710 soot_jimple_Stmt

// header file dependencies
// @dep_header java_lang_Boolean
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header org_dellroad_jc_cgen_escape_StackAlloc
// @dep_header soot_Local
// @dep_header soot_Value
// @dep_header soot_jimple_AssignStmt
// @dep_header soot_jimple_Stmt

#include "jc_defs.h"

#include "java/lang/Boolean.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "org/dellroad/jc/cgen/escape/StackAlloc.h"
#include "soot/Local.h"
#include "soot/Value.h"
#include "soot/jimple/AssignStmt.h"
#include "soot/jimple/Stmt.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// soot.jimple.AssignStmt stmt
static _jc_field _jc_org_dellroad_jc_cgen_escape_StackAlloc$field_info$stmt = {
	.name=		"stmt",
	.signature=	"Lsoot/jimple/AssignStmt;",
	.class=		&_jc_org_dellroad_jc_cgen_escape_StackAlloc$type,
	.type=		&_jc_soot_jimple_AssignStmt$type,
	.access_flags=	0,
	.offset=	_JC_OFFSETOF(_jc_org_dellroad_jc_cgen_escape_StackAlloc$object, refs[-1].org_dellroad_jc_cgen_escape_StackAlloc.stmt),
};

// soot.Local local
static _jc_field _jc_org_dellroad_jc_cgen_escape_StackAlloc$field_info$local = {
	.name=		"local",
	.signature=	"Lsoot/Local;",
	.class=		&_jc_org_dellroad_jc_cgen_escape_StackAlloc$type,
	.type=		&_jc_soot_Local$type,
	.access_flags=	0,
	.offset=	_JC_OFFSETOF(_jc_org_dellroad_jc_cgen_escape_StackAlloc$object, refs[-1].org_dellroad_jc_cgen_escape_StackAlloc.local),
};

// soot.Value value
static _jc_field _jc_org_dellroad_jc_cgen_escape_StackAlloc$field_info$value = {
	.name=		"value",
	.signature=	"Lsoot/Value;",
	.class=		&_jc_org_dellroad_jc_cgen_escape_StackAlloc$type,
	.type=		&_jc_soot_Value$type,
	.access_flags=	0,
	.offset=	_JC_OFFSETOF(_jc_org_dellroad_jc_cgen_escape_StackAlloc$object, refs[-1].org_dellroad_jc_cgen_escape_StackAlloc.value),
};

// java.lang.Boolean escapes
static _jc_field _jc_org_dellroad_jc_cgen_escape_StackAlloc$field_info$escapes = {
	.name=		"escapes",
	.signature=	"Ljava/lang/Boolean;",
	.class=		&_jc_org_dellroad_jc_cgen_escape_StackAlloc$type,
	.type=		&_jc_java_lang_Boolean$type,
	.access_flags=	0,
	.offset=	_JC_OFFSETOF(_jc_org_dellroad_jc_cgen_escape_StackAlloc$object, refs[-1].org_dellroad_jc_cgen_escape_StackAlloc.escapes),
};

// int size
static _jc_field _jc_org_dellroad_jc_cgen_escape_StackAlloc$field_info$size = {
	.name=		"size",
	.signature=	"I",
	.class=		&_jc_org_dellroad_jc_cgen_escape_StackAlloc$type,
	.type=		&_jc_int$prim$type,
	.access_flags=	0,
	.offset=	_JC_OFFSETOF(_jc_org_dellroad_jc_cgen_escape_StackAlloc$object, nonrefs.org_dellroad_jc_cgen_escape_StackAlloc.size),
};

// int cost
static _jc_field _jc_org_dellroad_jc_cgen_escape_StackAlloc$field_info$cost = {
	.name=		"cost",
	.signature=	"I",
	.class=		&_jc_org_dellroad_jc_cgen_escape_StackAlloc$type,
	.type=		&_jc_int$prim$type,
	.access_flags=	0,
	.offset=	_JC_OFFSETOF(_jc_org_dellroad_jc_cgen_escape_StackAlloc$object, nonrefs.org_dellroad_jc_cgen_escape_StackAlloc.cost),
};

// Fields
static _jc_field *const _jc_org_dellroad_jc_cgen_escape_StackAlloc$fields[] = {
	&_jc_org_dellroad_jc_cgen_escape_StackAlloc$field_info$escapes,
	&_jc_org_dellroad_jc_cgen_escape_StackAlloc$field_info$local,
	&_jc_org_dellroad_jc_cgen_escape_StackAlloc$field_info$stmt,
	&_jc_org_dellroad_jc_cgen_escape_StackAlloc$field_info$value,
	&_jc_org_dellroad_jc_cgen_escape_StackAlloc$field_info$cost,
	&_jc_org_dellroad_jc_cgen_escape_StackAlloc$field_info$size
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(soot.jimple.Stmt)
//

static _jc_linenum _jc_org_dellroad_jc_cgen_escape_StackAlloc$linenum_table$_init$3c88635eae989746[];

static const unsigned char _jc_org_dellroad_jc_cgen_escape_StackAlloc$param_ptypes$_init$3c88635eae989746[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_org_dellroad_jc_cgen_escape_StackAlloc$param_types$_init$3c88635eae989746[] = {
	&_jc_soot_jimple_Stmt$type
};

_jc_method _jc_org_dellroad_jc_cgen_escape_StackAlloc$method_info$_init$3c88635eae989746 = {
	.name=			"<init>",
	.signature=		"(Lsoot/jimple/Stmt;)V",
	.class=			&_jc_org_dellroad_jc_cgen_escape_StackAlloc$type,
	.param_types=		&_jc_org_dellroad_jc_cgen_escape_StackAlloc$param_types$_init$3c88635eae989746,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_org_dellroad_jc_cgen_escape_StackAlloc$param_ptypes$_init$3c88635eae989746,
	.signature_hash=	_JC_JLONG(0x3c88635eae989746),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_org_dellroad_jc_cgen_escape_StackAlloc$method$_init$3c88635eae989746,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	4,
	      .table=	_jc_org_dellroad_jc_cgen_escape_StackAlloc$linenum_table$_init$3c88635eae989746
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(org_dellroad_jc_cgen_escape_StackAlloc, _init$3c88635eae989746);

void _JC_JCNI_ATTR
_jc_org_dellroad_jc_cgen_escape_StackAlloc$method$_init$3c88635eae989746(_jc_env *const env, _jc_org_dellroad_jc_cgen_escape_StackAlloc$object *this, _jc_object *param0)
{
	struct _jc_org_dellroad_jc_cgen_escape_StackAlloc$object *r0;
	struct _jc_object *r1;
	struct _jc_object *r2;
	struct _jc_object *r3;
	struct _jc_object *r4;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(27);				// 0
	r2 = _JC_CAST(env, &_jc_soot_jimple_AssignStmt$type, r1);
	_JC_REF_FIELD(env, r0, org_dellroad_jc_cgen_escape_StackAlloc, stmt) = r2;
	_JC_LINE_NUMBER(28);				// 1
	r2 = _JC_REF_FIELD(env, r0, org_dellroad_jc_cgen_escape_StackAlloc, stmt);
	r3 = _JC_INVOKE_INTERFACE(env, r2, _JC_JLONG(0x81175b6a6f9b0911), _jc_object *, (_jc_env *, struct _jc_object *));
	r4 = _JC_CAST(env, &_jc_soot_Local$type, r3);
	_JC_REF_FIELD(env, r0, org_dellroad_jc_cgen_escape_StackAlloc, local) = r4;
	_JC_LINE_NUMBER(29);				// 2
	r2 = _JC_REF_FIELD(env, r0, org_dellroad_jc_cgen_escape_StackAlloc, stmt);
	r3 = _JC_INVOKE_INTERFACE(env, r2, _JC_JLONG(0xb163824a99afafb3), _jc_object *, (_jc_env *, struct _jc_object *));
	_JC_REF_FIELD(env, r0, org_dellroad_jc_cgen_escape_StackAlloc, value) = r3;
	_JC_LINE_NUMBER(30);				// 3
	return;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_org_dellroad_jc_cgen_escape_StackAlloc$methods[] = {
	&_jc_org_dellroad_jc_cgen_escape_StackAlloc$method_info$_init$3c88635eae989746
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_org_dellroad_jc_cgen_escape_StackAlloc$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};
static _jc_type *const _jc_org_dellroad_jc_cgen_escape_StackAlloc$instanceof_hash_bucket_102[] = {
	&_jc_org_dellroad_jc_cgen_escape_StackAlloc$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_org_dellroad_jc_cgen_escape_StackAlloc$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[101]=	_jc_org_dellroad_jc_cgen_escape_StackAlloc$instanceof_hash_bucket_101,
	[102]=	_jc_org_dellroad_jc_cgen_escape_StackAlloc$instanceof_hash_bucket_102
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_org_dellroad_jc_cgen_escape_StackAlloc$class_depends[] = {
	{ "java/lang/Boolean",	_JC_JLONG(0x52a05cb5e85a24ee) },
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "soot/Local",	_JC_JLONG(0xfc12513d0e867dd9) },
	{ "soot/Value",	_JC_JLONG(0x277f133500573bf0) },
	{ "soot/jimple/AssignStmt",	_JC_JLONG(0xbfceec22e8ffee79) },
	{ "soot/jimple/Stmt",	_JC_JLONG(0x3650ad26817a710) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_org_dellroad_jc_cgen_escape_StackAlloc$vtype _jc_org_dellroad_jc_cgen_escape_StackAlloc$type = {
    .type= {
	.name=			"org/dellroad/jc/cgen/escape/StackAlloc",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		0,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		11,
		.hash=			_JC_JLONG(0xe19a02dee62a8866),
		.source_file=		"StackAlloc.java",
		.instance_size=		sizeof(_jc_org_dellroad_jc_cgen_escape_StackAlloc$refs) + sizeof(_jc_org_dellroad_jc_cgen_escape_StackAlloc$object),
		.num_virtual_refs=	4,
		.num_fields=		sizeof(_jc_org_dellroad_jc_cgen_escape_StackAlloc$fields) / sizeof(*_jc_org_dellroad_jc_cgen_escape_StackAlloc$fields),
		.fields=		_jc_org_dellroad_jc_cgen_escape_StackAlloc$fields,
		.num_methods=		sizeof(_jc_org_dellroad_jc_cgen_escape_StackAlloc$methods) / sizeof(*_jc_org_dellroad_jc_cgen_escape_StackAlloc$methods),
		.methods=		_jc_org_dellroad_jc_cgen_escape_StackAlloc$methods,
		.instanceof_hash_table=	_jc_org_dellroad_jc_cgen_escape_StackAlloc$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_org_dellroad_jc_cgen_escape_StackAlloc$class_depends) / sizeof(*_jc_org_dellroad_jc_cgen_escape_StackAlloc$class_depends),
		.class_depends=		_jc_org_dellroad_jc_cgen_escape_StackAlloc$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.org_dellroad_jc_cgen_escape_StackAlloc= {
	},
    }
};
